summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/galleryexport
diff options
context:
space:
mode:
Diffstat (limited to 'kipi-plugins/galleryexport')
-rw-r--r--kipi-plugins/galleryexport/TODO2
-rw-r--r--kipi-plugins/galleryexport/galleries.cpp70
-rw-r--r--kipi-plugins/galleryexport/galleries.h46
-rw-r--r--kipi-plugins/galleryexport/galleryalbumdialog.ui32
-rw-r--r--kipi-plugins/galleryexport/galleryconfig.cpp72
-rw-r--r--kipi-plugins/galleryexport/galleryconfig.h23
-rw-r--r--kipi-plugins/galleryexport/galleryitem.h28
-rw-r--r--kipi-plugins/galleryexport/gallerylist.cpp76
-rw-r--r--kipi-plugins/galleryexport/gallerylist.h9
-rw-r--r--kipi-plugins/galleryexport/gallerympform.cpp52
-rw-r--r--kipi-plugins/galleryexport/gallerympform.h20
-rw-r--r--kipi-plugins/galleryexport/gallerytalker.cpp184
-rw-r--r--kipi-plugins/galleryexport/gallerytalker.h61
-rw-r--r--kipi-plugins/galleryexport/galleryviewitem.cpp24
-rw-r--r--kipi-plugins/galleryexport/galleryviewitem.h18
-rw-r--r--kipi-plugins/galleryexport/gallerywidget.cpp100
-rw-r--r--kipi-plugins/galleryexport/gallerywidget.h29
-rw-r--r--kipi-plugins/galleryexport/gallerywindow.cpp176
-rw-r--r--kipi-plugins/galleryexport/gallerywindow.h55
-rw-r--r--kipi-plugins/galleryexport/plugin_galleryexport.cpp34
-rw-r--r--kipi-plugins/galleryexport/plugin_galleryexport.h7
21 files changed, 562 insertions, 556 deletions
diff --git a/kipi-plugins/galleryexport/TODO b/kipi-plugins/galleryexport/TODO
index fcff8e0..7a3d8b6 100644
--- a/kipi-plugins/galleryexport/TODO
+++ b/kipi-plugins/galleryexport/TODO
@@ -10,4 +10,4 @@ Somewhat immediate implementation needed:
For the lazy times:
* Polish the html code used to render the thumbnails, better
- fonts sizes and layout
+ fonts sizes and tqlayout
diff --git a/kipi-plugins/galleryexport/galleries.cpp b/kipi-plugins/galleryexport/galleries.cpp
index c38baff..eddaba5 100644
--- a/kipi-plugins/galleryexport/galleries.cpp
+++ b/kipi-plugins/galleryexport/galleries.cpp
@@ -16,9 +16,9 @@
* GNU General Public License for more details.
* ============================================================ */
-#include <qstring.h>
+#include <tqstring.h>
-#include <qwidget.h>
+#include <tqwidget.h>
#include <kapplication.h>
#include <kdebug.h>
#include <kconfig.h>
@@ -34,8 +34,8 @@ namespace KIPIGalleryExportPlugin
{
-Gallery::Gallery(const QString& name, const QString& url,
- const QString& username, const QString& password,
+Gallery::Gallery(const TQString& name, const TQString& url,
+ const TQString& username, const TQString& password,
const unsigned int version,
const unsigned int galleryId)
: mName(name),
@@ -53,41 +53,41 @@ Gallery::~Gallery()
}
-QString Gallery::name() const { return mName; }
-QString Gallery::url() const { return mUrl; }
-QString Gallery::username() const { return mUsername; }
-QString Gallery::password() const { return mPassword; }
+TQString Gallery::name() const { return mName; }
+TQString Gallery::url() const { return mUrl; }
+TQString Gallery::username() const { return mUsername; }
+TQString Gallery::password() const { return mPassword; }
unsigned int Gallery::version() const { return mVersion; }
unsigned int Gallery::galleryId() const { return mGalleryId; }
-void Gallery::setName(QString name) { mName = name; }
-void Gallery::setUrl(QString url) { mUrl = url; }
-void Gallery::setUsername(QString username) { mUsername = username; }
-void Gallery::setPassword(QString password) { mPassword = password; }
+void Gallery::setName(TQString name) { mName = name; }
+void Gallery::setUrl(TQString url) { mUrl = url; }
+void Gallery::setUsername(TQString username) { mUsername = username; }
+void Gallery::setPassword(TQString password) { mPassword = password; }
void Gallery::setVersion(unsigned int version) { mVersion = version; }
void Gallery::setGalleryId(unsigned int galleryId) { mGalleryId = galleryId; }
-QListViewItem* Gallery::asQListViewItem(QListView* pParent)
+TQListViewItem* Gallery::asTQListViewItem(TQListView* pParent)
{
- QListViewItem* p_lvi = (QListViewItem*) new GalleryQListViewItem(this, pParent);
+ TQListViewItem* p_lvi = (TQListViewItem*) new GalleryTQListViewItem(this, pParent);
return p_lvi;
}
-GalleryQListViewItem::GalleryQListViewItem(Gallery* pGallery, QListView* pParent)
- : QListViewItem(pParent, pGallery->name(), pGallery->url(), pGallery->username()),
+GalleryTQListViewItem::GalleryTQListViewItem(Gallery* pGallery, TQListView* pParent)
+ : TQListViewItem(pParent, pGallery->name(), pGallery->url(), pGallery->username()),
mpGallery(pGallery)
{
}
-Gallery* GalleryQListViewItem::GetGallery()
+Gallery* GalleryTQListViewItem::GetGallery()
{
return mpGallery;
}
-void GalleryQListViewItem::Refresh()
+void GalleryTQListViewItem::Refresh()
{
setText(0, mpGallery->name());
setText(1, mpGallery->url());
@@ -144,12 +144,12 @@ void Galleries::Load()
// read config
KConfig config("kipirc");
config.setGroup("GallerySync Settings");
- QValueList<int> gallery_ids = config.readIntListEntry("Galleries");
+ TQValueList<int> gallery_ids = config.readIntListEntry("Galleries");
config.setGroup("GallerySync Galleries");
- QString name, url, username, password = "";
+ TQString name, url, username, password = "";
int version;
- for (QValueList<int>::Iterator it = gallery_ids.begin(); it != gallery_ids.end(); ++it)
+ for (TQValueList<int>::Iterator it = gallery_ids.begin(); it != gallery_ids.end(); ++it)
{
unsigned int gallery_id = (*it);
@@ -157,12 +157,12 @@ void Galleries::Load()
mMaxGalleryId = gallery_id;
// Load the gallery with this id.
- name = config.readEntry(QString("Name%1").arg(gallery_id));
- url = config.readEntry(QString("URL%1").arg(gallery_id));
- username = config.readEntry(QString("Username%1").arg(gallery_id));
- version = config.readNumEntry(QString("Version%1").arg(gallery_id));
+ name = config.readEntry(TQString("Name%1").tqarg(gallery_id));
+ url = config.readEntry(TQString("URL%1").tqarg(gallery_id));
+ username = config.readEntry(TQString("Username%1").tqarg(gallery_id));
+ version = config.readNumEntry(TQString("Version%1").tqarg(gallery_id));
if (bln_use_wallet)
- mpWallet->readPassword(QString("Password%1").arg(gallery_id), password);
+ mpWallet->readPassword(TQString("Password%1").tqarg(gallery_id), password);
Gallery* p_gallery = new Gallery(name, url, username, password, version, gallery_id);
mGalleries.append(p_gallery);
@@ -187,7 +187,7 @@ void Galleries::Remove(Gallery* pGallery)
void Galleries::Save()
{
- QValueList<int> gallery_ids;
+ TQValueList<int> gallery_ids;
KConfig config("kipirc");
config.deleteGroup("GallerySync Galleries");
config.setGroup("GallerySync Galleries");
@@ -217,23 +217,23 @@ void Galleries::Save()
unsigned int gallery_id = p_gallery->galleryId();
gallery_ids.append(gallery_id);
- config.writeEntry(QString("Name%1").arg(gallery_id), p_gallery->name());
- config.writeEntry(QString("URL%1").arg(gallery_id), p_gallery->url());
- config.writeEntry(QString("Username%1").arg(gallery_id), p_gallery->username());
- config.writeEntry(QString("Version%1").arg(gallery_id), p_gallery->version());
+ config.writeEntry(TQString("Name%1").tqarg(gallery_id), p_gallery->name());
+ config.writeEntry(TQString("URL%1").tqarg(gallery_id), p_gallery->url());
+ config.writeEntry(TQString("Username%1").tqarg(gallery_id), p_gallery->username());
+ config.writeEntry(TQString("Version%1").tqarg(gallery_id), p_gallery->version());
if (bln_use_wallet)
- mpWallet->writePassword(QString("Password%1").arg(gallery_id), p_gallery->password());
+ mpWallet->writePassword(TQString("Password%1").tqarg(gallery_id), p_gallery->password());
}
config.setGroup("GallerySync Settings");
config.writeEntry("Galleries", gallery_ids);
}
-QListView* Galleries::asQListView(QWidget* pParent)
+TQListView* Galleries::asTQListView(TQWidget* pParent)
{
Load();
- QListView* p_lv = new QListView (pParent);
+ TQListView* p_lv = new TQListView (pParent);
p_lv->addColumn(i18n("Gallery Name"));
p_lv->addColumn(i18n("URL"));
p_lv->addColumn(i18n("User"));
@@ -241,7 +241,7 @@ QListView* Galleries::asQListView(QWidget* pParent)
for (GalleryPtrList::iterator it = mGalleries.begin(); it != mGalleries.end(); ++it)
{
- (*it)->asQListViewItem(p_lv);
+ (*it)->asTQListViewItem(p_lv);
}
return p_lv;
diff --git a/kipi-plugins/galleryexport/galleries.h b/kipi-plugins/galleryexport/galleries.h
index c9a8dd1..009db38 100644
--- a/kipi-plugins/galleryexport/galleries.h
+++ b/kipi-plugins/galleryexport/galleries.h
@@ -19,8 +19,8 @@
#ifndef GALLERIES_H
#define GALLERIES_H
-#include <qptrlist.h>
-#include <qlistview.h>
+#include <tqptrlist.h>
+#include <tqlistview.h>
namespace KWallet
{
@@ -34,36 +34,36 @@ class Gallery
{
public:
- Gallery(const QString& name = i18n("New Gallery"),
- const QString& url = QString("http://www.newgallery.com/"),
- const QString& username = QString(),
- const QString& password = QString(),
+ Gallery(const TQString& name = i18n("New Gallery"),
+ const TQString& url = TQString("http://www.newgallery.com/"),
+ const TQString& username = TQString(),
+ const TQString& password = TQString(),
const unsigned int version = 2,
const unsigned int galleryId = 0);
~Gallery();
- QString name() const;
- QString url() const;
- QString username() const;
- QString password() const;
+ TQString name() const;
+ TQString url() const;
+ TQString username() const;
+ TQString password() const;
unsigned int version() const;
unsigned int galleryId() const;
- void setName(QString name);
- void setUrl(QString url);
- void setUsername(QString username);
- void setPassword(QString password);
+ void setName(TQString name);
+ void setUrl(TQString url);
+ void setUsername(TQString username);
+ void setPassword(TQString password);
void setVersion(unsigned int version);
void setGalleryId(unsigned int galleryId);
- QListViewItem* asQListViewItem(QListView* pParent);
+ TQListViewItem* asTQListViewItem(TQListView* pParent);
private:
- QString mName;
- QString mUrl;
- QString mUsername;
- QString mPassword;
+ TQString mName;
+ TQString mUrl;
+ TQString mUsername;
+ TQString mPassword;
unsigned int mVersion;
unsigned int mGalleryId;
@@ -71,10 +71,10 @@ private:
/* Simple Stub Class to allow easy access to Galleries from GUI elements */
-class GalleryQListViewItem : public QListViewItem
+class GalleryTQListViewItem : public TQListViewItem
{
public:
- GalleryQListViewItem(Gallery* pGallery, QListView* pParent);
+ GalleryTQListViewItem(Gallery* pGallery, TQListView* pParent);
Gallery* GetGallery();
void Refresh();
@@ -83,7 +83,7 @@ private:
};
-typedef QPtrList<Gallery> GalleryPtrList;
+typedef TQPtrList<Gallery> GalleryPtrList;
/* Container class for all Galleries */
class Galleries
@@ -95,7 +95,7 @@ public:
void Add(Gallery* pGallery);
void Remove(Gallery* pGallery);
void Save();
- QListView* asQListView(QWidget* pParent);
+ TQListView* asTQListView(TQWidget* pParent);
private:
void Load();
diff --git a/kipi-plugins/galleryexport/galleryalbumdialog.ui b/kipi-plugins/galleryexport/galleryalbumdialog.ui
index 2dfbf6a..0ec158a 100644
--- a/kipi-plugins/galleryexport/galleryalbumdialog.ui
+++ b/kipi-plugins/galleryexport/galleryalbumdialog.ui
@@ -1,10 +1,10 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>KIPIGalleryExportPlugin::GalleryAlbumDialog</class>
-<widget class="QDialog">
+<widget class="TQDialog">
<property name="name">
<cstring>GalleryAlbumDialog</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>0</x>
<y>0</y>
@@ -28,7 +28,7 @@
<property name="spacing">
<number>5</number>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>header</cstring>
</property>
@@ -50,15 +50,15 @@
<enum>Horizontal</enum>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout3</cstring>
+ <cstring>tqlayout3</cstring>
</property>
<grid>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>titleLabel</cstring>
</property>
@@ -66,7 +66,7 @@
<string>Title (optional):</string>
</property>
</widget>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>nameLabel</cstring>
</property>
@@ -74,7 +74,7 @@
<string>Name (optional):</string>
</property>
</widget>
- <widget class="QLabel" row="2" column="0">
+ <widget class="TQLabel" row="2" column="0">
<property name="name">
<cstring>captionLabel</cstring>
</property>
@@ -82,17 +82,17 @@
<string>Caption (optional):</string>
</property>
</widget>
- <widget class="QLineEdit" row="0" column="1">
+ <widget class="TQLineEdit" row="0" column="1">
<property name="name">
<cstring>titleEdit</cstring>
</property>
</widget>
- <widget class="QLineEdit" row="1" column="1">
+ <widget class="TQLineEdit" row="1" column="1">
<property name="name">
<cstring>nameEdit</cstring>
</property>
</widget>
- <widget class="QLineEdit" row="2" column="1">
+ <widget class="TQLineEdit" row="2" column="1">
<property name="name">
<cstring>captionEdit</cstring>
</property>
@@ -113,7 +113,7 @@
<enum>Horizontal</enum>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout1</cstring>
</property>
@@ -137,14 +137,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
</size>
</property>
</spacer>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>buttonOk</cstring>
</property>
@@ -161,7 +161,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>buttonCancel</cstring>
</property>
@@ -193,5 +193,5 @@
<slot>reject()</slot>
</connection>
</connections>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kipi-plugins/galleryexport/galleryconfig.cpp b/kipi-plugins/galleryexport/galleryconfig.cpp
index 65fd7f4..9fc79f4 100644
--- a/kipi-plugins/galleryexport/galleryconfig.cpp
+++ b/kipi-plugins/galleryexport/galleryconfig.cpp
@@ -17,18 +17,18 @@
*
* ============================================================ */
-// Include files for Qt
-
-#include <qlistview.h>
-#include <qpushbutton.h>
-#include <qtimer.h>
-#include <qpixmap.h>
-#include <qcursor.h>
-#include <qlineedit.h>
-#include <qprogressdialog.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qlayout.h>
+// Include files for TQt
+
+#include <tqlistview.h>
+#include <tqpushbutton.h>
+#include <tqtimer.h>
+#include <tqpixmap.h>
+#include <tqcursor.h>
+#include <tqlineedit.h>
+#include <tqprogressdialog.h>
+#include <tqspinbox.h>
+#include <tqcheckbox.h>
+#include <tqlayout.h>
// Include files for KDE
@@ -56,75 +56,75 @@
namespace KIPIGalleryExportPlugin
{
-GalleryEdit::GalleryEdit(QWidget* pParent,
+GalleryEdit::GalleryEdit(TQWidget* pParent,
Gallery* pGallery,
- QString title)
+ TQString title)
: KDialogBase(pParent, 0, true, title, Ok|Cancel, Ok, false),
mpGallery(pGallery)
{
setButtonGuiItem( Ok, KStdGuiItem::save() );
- QFrame *page = new QFrame (this);
- QHBoxLayout *tll = new QHBoxLayout(page);
+ TQFrame *page = new TQFrame (this);
+ TQHBoxLayout *tll = new TQHBoxLayout(page);
page->setMinimumSize (500, 200);
setMainWidget(page);
- QVBoxLayout* vbox = new QVBoxLayout();
+ TQVBoxLayout* vbox = new TQVBoxLayout();
vbox->setSpacing (KDialog::spacingHint());
tll->addItem(vbox);
- mpHeaderLabel = new QLabel(page);
- mpHeaderLabel->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,
- QSizePolicy::Fixed));
+ mpHeaderLabel = new TQLabel(page);
+ mpHeaderLabel->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Minimum,
+ TQSizePolicy::Fixed));
mpHeaderLabel->setText(title);
vbox->addWidget(mpHeaderLabel);
- QFrame* hline = new QFrame(page, "hline");
- hline->setFrameShape(QFrame::HLine);
- hline->setFrameShadow(QFrame::Sunken);
- hline->setFrameShape(QFrame::HLine);
+ TQFrame* hline = new TQFrame(page, "hline");
+ hline->setFrameShape(TQFrame::HLine);
+ hline->setFrameShadow(TQFrame::Sunken);
+ hline->setFrameShape(TQFrame::HLine);
vbox->addWidget(hline);
- QGridLayout* centerLayout = new QGridLayout(0, 1, 1, 5, 5);
+ TQGridLayout* centerLayout = new TQGridLayout(0, 1, 1, 5, 5);
- mpNameEdit = new QLineEdit( this );
+ mpNameEdit = new TQLineEdit( this );
centerLayout->addWidget(mpNameEdit, 0, 1);
- mpUrlEdit = new QLineEdit( this );
+ mpUrlEdit = new TQLineEdit( this );
centerLayout->addWidget(mpUrlEdit, 1, 1);
- mpUsernameEdit = new QLineEdit( this );
+ mpUsernameEdit = new TQLineEdit( this );
centerLayout->addWidget(mpUsernameEdit, 2, 1);
- mpPasswordEdit = new QLineEdit( this );
- mpPasswordEdit->setEchoMode(QLineEdit::Password);
+ mpPasswordEdit = new TQLineEdit( this );
+ mpPasswordEdit->setEchoMode(TQLineEdit::Password);
centerLayout->addWidget(mpPasswordEdit, 3, 1);
- QLabel* name_label = new QLabel(this);
+ TQLabel* name_label = new TQLabel(this);
name_label->setText(i18n( "Name:" ));
centerLayout->addWidget(name_label, 0, 0);
- QLabel* urlLabel = new QLabel(this);
+ TQLabel* urlLabel = new TQLabel(this);
urlLabel->setText(i18n( "URL:" ));
centerLayout->addWidget(urlLabel, 1, 0);
- QLabel* nameLabel = new QLabel(this);
+ TQLabel* nameLabel = new TQLabel(this);
nameLabel->setText(i18n( "Username:" ));
centerLayout->addWidget(nameLabel, 2, 0);
- QLabel* passwdLabel = new QLabel(this);
+ TQLabel* passwdLabel = new TQLabel(this);
passwdLabel->setText(i18n( "Password:" ));
centerLayout->addWidget(passwdLabel, 3, 0);
//---------------------------------------------
- mpGalleryVersion = new QCheckBox( i18n("Use &Gallery 2"), this);
+ mpGalleryVersion = new TQCheckBox( i18n("Use &Gallery 2"), this);
mpGalleryVersion->setChecked( 2 == pGallery->version() );
centerLayout->addWidget( mpGalleryVersion, 4, 1 );
//---------------------------------------------
vbox->addLayout( centerLayout );
- resize( QSize(300, 150).expandedTo(minimumSizeHint()) );
+ resize( TQSize(300, 150).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
mpNameEdit->setText(pGallery->name());
diff --git a/kipi-plugins/galleryexport/galleryconfig.h b/kipi-plugins/galleryexport/galleryconfig.h
index 0aaedcc..a5945ac 100644
--- a/kipi-plugins/galleryexport/galleryconfig.h
+++ b/kipi-plugins/galleryexport/galleryconfig.h
@@ -20,9 +20,9 @@
#define GALLERYCONFIG_H
#include <kdialogbase.h>
-#include <qvaluelist.h>
-#include <qpair.h>
-#include <qintdict.h>
+#include <tqvaluelist.h>
+#include <tqpair.h>
+#include <tqintdict.h>
namespace KIPIGalleryExportPlugin
{
@@ -32,23 +32,24 @@ class Gallery;
class GalleryEdit : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- GalleryEdit(QWidget* pParent,
+ GalleryEdit(TQWidget* pParent,
Gallery* pGallery,
- QString title);
+ TQString title);
~GalleryEdit();
private:
Gallery* mpGallery;
- QLabel* mpHeaderLabel;
- QLineEdit* mpNameEdit;
- QLineEdit* mpUrlEdit;
- QLineEdit* mpUsernameEdit;
- QLineEdit* mpPasswordEdit;
- QCheckBox* mpGalleryVersion;
+ TQLabel* mpHeaderLabel;
+ TQLineEdit* mpNameEdit;
+ TQLineEdit* mpUrlEdit;
+ TQLineEdit* mpUsernameEdit;
+ TQLineEdit* mpPasswordEdit;
+ TQCheckBox* mpGalleryVersion;
private slots:
void slotOk(void);
diff --git a/kipi-plugins/galleryexport/galleryitem.h b/kipi-plugins/galleryexport/galleryitem.h
index 89661ec..a752698 100644
--- a/kipi-plugins/galleryexport/galleryitem.h
+++ b/kipi-plugins/galleryexport/galleryitem.h
@@ -22,7 +22,7 @@
#ifndef GALLERYITEM_H
#define GALLERYITEM_H
-#include <qstring.h>
+#include <tqstring.h>
namespace KIPIGalleryExportPlugin
{
@@ -38,10 +38,10 @@ public:
int ref_num;
int album_num;
- QString name;
- QString caption;
- QString thumbName;
- QString albumURL;
+ TQString name;
+ TQString caption;
+ TQString thumbName;
+ TQString albumURL;
};
class GAlbum
@@ -51,7 +51,7 @@ public:
GAlbum()
{
ref_num = -1;
- parent_ref_num = -1;
+ tqparent_ref_num = -1;
add = false;
write = false;
@@ -62,19 +62,19 @@ public:
bool operator<(const GAlbum& rhs) const
{
- if (parent_ref_num == rhs.parent_ref_num)
+ if (tqparent_ref_num == rhs.tqparent_ref_num)
return ref_num < rhs.ref_num;
- return parent_ref_num < rhs.parent_ref_num;
+ return tqparent_ref_num < rhs.tqparent_ref_num;
}
int ref_num;
- int parent_ref_num;
- QString name;
- QString parentName;
- QString title;
- QString summary;
- QString baseurl;
+ int tqparent_ref_num;
+ TQString name;
+ TQString tqparentName;
+ TQString title;
+ TQString summary;
+ TQString baseurl;
bool add;
bool write;
diff --git a/kipi-plugins/galleryexport/gallerylist.h b/kipi-plugins/galleryexport/gallerylist.h
index f4aacd0..9216dda 100644
--- a/kipi-plugins/galleryexport/gallerylist.h
+++ b/kipi-plugins/galleryexport/gallerylist.h
@@ -21,7 +21,7 @@
#include <kdialogbase.h>
-#include <qlistview.h>
+#include <tqlistview.h>
namespace KIPIGalleryExportPlugin
{
@@ -32,10 +32,11 @@ class Galleries;
class GalleryList : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- GalleryList(QWidget *parent, Galleries* pGalleries, bool blnShowOpen = true);
+ GalleryList(TQWidget *tqparent, Galleries* pGalleries, bool blnShowOpen = true);
~GalleryList();
Gallery* GetGallery(void);
@@ -44,12 +45,12 @@ private:
Galleries* mpGalleries;
Gallery* mpCurrentGallery;
- QListView* mpGalleryList;
+ TQListView* mpGalleryList;
private slots:
void selectionChanged();
- void doubleClicked(QListViewItem*, const QPoint&, int);
+ void doubleClicked(TQListViewItem*, const TQPoint&, int);
void slotUser1();
void slotUser2();
diff --git a/kipi-plugins/galleryexport/gallerympform.cpp b/kipi-plugins/galleryexport/gallerympform.cpp
index f3cf894..5161bc2 100644
--- a/kipi-plugins/galleryexport/gallerympform.cpp
+++ b/kipi-plugins/galleryexport/gallerympform.cpp
@@ -24,9 +24,9 @@
#include <kmimetype.h>
#include <kurl.h>
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qtextstream.h>
+#include <tqfile.h>
+#include <tqfileinfo.h>
+#include <tqtextstream.h>
#include <cstring>
#include <cstdio>
@@ -45,7 +45,7 @@ GalleryMPForm::GalleryMPForm()
if (GalleryTalker::isGallery2())
{
addPairRaw("g2_controller", "remote:GalleryRemote");
- QString auth_token = GalleryTalker::getAuthToken();
+ TQString auth_token = GalleryTalker::getAuthToken();
if (!auth_token.isEmpty())
addPairRaw("g2_authToken", auth_token);
}
@@ -62,28 +62,28 @@ void GalleryMPForm::reset()
void GalleryMPForm::finish()
{
- QCString str;
+ TQCString str;
str += "--";
str += m_boundary;
str += "--";
str += "\r\n";
- QTextStream ts(m_buffer, IO_Append|IO_WriteOnly);
- ts.setEncoding(QTextStream::UnicodeUTF8);
+ TQTextStream ts(m_buffer, IO_Append|IO_WriteOnly);
+ ts.setEncoding(TQTextStream::UnicodeUTF8);
ts << str << '\0';
}
-bool GalleryMPForm::addPair(const QString& name, const QString& value)
+bool GalleryMPForm::addPair(const TQString& name, const TQString& value)
{
if (GalleryTalker::isGallery2())
- return addPairRaw(QString("g2_form[%1]").arg(name), value);
+ return addPairRaw(TQString("g2_form[%1]").tqarg(name), value);
return addPairRaw(name, value);
}
-bool GalleryMPForm::addPairRaw(const QString& name, const QString& value)
+bool GalleryMPForm::addPairRaw(const TQString& name, const TQString& value)
{
- QCString str;
+ TQCString str;
str += "--";
str += m_boundary;
@@ -99,16 +99,16 @@ bool GalleryMPForm::addPairRaw(const QString& name, const QString& value)
//m_buffer.resize(oldSize + str.size());
//memcpy(m_buffer.data() + oldSize, str.data(), str.size());
- QTextStream ts(m_buffer, IO_Append|IO_WriteOnly);
- ts.setEncoding(QTextStream::UnicodeUTF8);
+ TQTextStream ts(m_buffer, IO_Append|IO_WriteOnly);
+ ts.setEncoding(TQTextStream::UnicodeUTF8);
ts << str;
return true;
}
-bool GalleryMPForm::addFile(const QString& path, const QString& displayFilename)
+bool GalleryMPForm::addFile(const TQString& path, const TQString& displayFilename)
{
- QString filename = "userfile_name";
+ TQString filename = "userfile_name";
if (GalleryTalker::isGallery2())
filename = "g2_userfile_name";
@@ -118,7 +118,7 @@ bool GalleryMPForm::addFile(const QString& path, const QString& displayFilename)
}
KMimeType::Ptr ptr = KMimeType::findByURL(path);
- QString mime = ptr->name();
+ TQString mime = ptr->name();
if (mime.isEmpty())
{
// if we ourselves can't determine the mime of the local file,
@@ -126,13 +126,13 @@ bool GalleryMPForm::addFile(const QString& path, const QString& displayFilename)
return false;
}
- QFile imageFile(path);
+ TQFile imageFile(path);
if ( !imageFile.open( IO_ReadOnly ) )
return false;
- QByteArray imageData = imageFile.readAll();
+ TQByteArray imageData = imageFile.readAll();
imageFile.close();
- QCString str;
+ TQCString str;
str += "--";
str += m_boundary;
@@ -144,15 +144,15 @@ bool GalleryMPForm::addFile(const QString& path, const QString& displayFilename)
str += "userfile";
str += "\"; ";
str += "filename=\"";
- str += QFile::encodeName(KURL(path).filename());
+ str += TQFile::encodeName(KURL(path).filename());
str += "\"";
str += "\r\n";
str += "Content-Type: ";
str += mime.ascii();
str += "\r\n\r\n";
- QTextStream ts(m_buffer, IO_Append|IO_WriteOnly);
- ts.setEncoding(QTextStream::UnicodeUTF8);
+ TQTextStream ts(m_buffer, IO_Append|IO_WriteOnly);
+ ts.setEncoding(TQTextStream::UnicodeUTF8);
ts << str;
int oldSize = m_buffer.size();
@@ -164,17 +164,17 @@ bool GalleryMPForm::addFile(const QString& path, const QString& displayFilename)
return true;
}
-QString GalleryMPForm::contentType() const
+TQString GalleryMPForm::contentType() const
{
- return QString("Content-Type: multipart/form-data; boundary=" + m_boundary);
+ return TQString("Content-Type: multipart/form-data; boundary=" + m_boundary);
}
-QString GalleryMPForm::boundary() const
+TQString GalleryMPForm::boundary() const
{
return m_boundary;
}
-QByteArray GalleryMPForm::formData() const
+TQByteArray GalleryMPForm::formData() const
{
return m_buffer;
}
diff --git a/kipi-plugins/galleryexport/gallerympform.h b/kipi-plugins/galleryexport/gallerympform.h
index 10c6bfc..0c0a6f2 100644
--- a/kipi-plugins/galleryexport/gallerympform.h
+++ b/kipi-plugins/galleryexport/gallerympform.h
@@ -19,8 +19,8 @@
#ifndef GALLERYMPFORM_H
#define GALLERYMPFORM_H
-#include <qcstring.h>
-#include <qstring.h>
+#include <tqcstring.h>
+#include <tqstring.h>
class KURL;
@@ -37,19 +37,19 @@ public:
void finish();
void reset();
- bool addPair(const QString& name, const QString& value);
- bool addFile(const QString& path, const QString& displayFilename);
+ bool addPair(const TQString& name, const TQString& value);
+ bool addFile(const TQString& path, const TQString& displayFilename);
- QString contentType() const;
- QByteArray formData() const;
- QString boundary() const;
+ TQString contentType() const;
+ TQByteArray formData() const;
+ TQString boundary() const;
private:
- bool addPairRaw(const QString& name, const QString& value);
+ bool addPairRaw(const TQString& name, const TQString& value);
- QByteArray m_buffer;
- QCString m_boundary;
+ TQByteArray m_buffer;
+ TQCString m_boundary;
};
}
diff --git a/kipi-plugins/galleryexport/gallerytalker.cpp b/kipi-plugins/galleryexport/gallerytalker.cpp
index e18a7b0..10043dd 100644
--- a/kipi-plugins/galleryexport/gallerytalker.cpp
+++ b/kipi-plugins/galleryexport/gallerytalker.cpp
@@ -19,11 +19,11 @@
*
* ============================================================ */
-#include <qcstring.h>
-#include <qtextstream.h>
-#include <qfile.h>
-#include <qimage.h>
-#include <qregexp.h>
+#include <tqcstring.h>
+#include <tqtextstream.h>
+#include <tqfile.h>
+#include <tqimage.h>
+#include <tqregexp.h>
#include <klocale.h>
#include <kio/job.h>
@@ -45,8 +45,8 @@
namespace KIPIGalleryExportPlugin
{
-GalleryTalker::GalleryTalker( QWidget* parent )
- : m_parent( parent ), m_job( 0 ), m_loggedIn( false )
+GalleryTalker::GalleryTalker( TQWidget* tqparent )
+ : m_parent( tqparent ), m_job( 0 ), m_loggedIn( false )
{
}
@@ -57,15 +57,15 @@ GalleryTalker::~GalleryTalker()
}
bool GalleryTalker::s_using_gallery2 = true;
-QString GalleryTalker::s_authToken = "";
+TQString GalleryTalker::s_authToken = "";
bool GalleryTalker::loggedIn() const
{
return m_loggedIn;
}
-void GalleryTalker::login( const KURL& url, const QString& name,
- const QString& passwd )
+void GalleryTalker::login( const KURL& url, const TQString& name,
+ const TQString& passwd )
{
m_url = url;
@@ -80,10 +80,10 @@ void GalleryTalker::login( const KURL& url, const QString& name,
KIO::TransferJob* job = KIO::http_post(m_url, form.formData(), false);
job->addMetaData("content-type", form.contentType() );
job->addMetaData("cookies", "manual");
- connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
- SLOT(data(KIO::Job*, const QByteArray&)));
- connect(job, SIGNAL(result(KIO::Job *)),
- SLOT(slotResult(KIO::Job *)));
+ connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
+ TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
+ connect(job, TQT_SIGNAL(result(KIO::Job *)),
+ TQT_SLOT(slotResult(KIO::Job *)));
m_state = GE_LOGIN;
m_job = job;
@@ -95,7 +95,7 @@ void GalleryTalker::listAlbums()
{
GalleryMPForm form;
- QString task = "fetch-albums";
+ TQString task = "fetch-albums";
if (s_using_gallery2)
task = "fetch-albums-prune";
@@ -107,10 +107,10 @@ void GalleryTalker::listAlbums()
job->addMetaData("content-type", form.contentType() );
job->addMetaData("cookies", "manual");
job->addMetaData("setcookies", m_cookie);
- connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
- SLOT(data(KIO::Job*, const QByteArray&)));
- connect(job, SIGNAL(result(KIO::Job *)),
- SLOT(slotResult(KIO::Job *)));
+ connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
+ TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
+ connect(job, TQT_SIGNAL(result(KIO::Job *)),
+ TQT_SLOT(slotResult(KIO::Job *)));
m_state = GE_LISTALBUMS;
m_job = job;
@@ -118,7 +118,7 @@ void GalleryTalker::listAlbums()
emit signalBusy( true );
}
-void GalleryTalker::listPhotos( const QString& albumName )
+void GalleryTalker::listPhotos( const TQString& albumName )
{
if (m_job)
{
@@ -137,10 +137,10 @@ void GalleryTalker::listPhotos( const QString& albumName )
job->addMetaData("content-type", form.contentType() );
job->addMetaData("cookies", "manual");
job->addMetaData("setcookies", m_cookie);
- connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
- SLOT(data(KIO::Job*, const QByteArray&)));
- connect(job, SIGNAL(result(KIO::Job *)),
- SLOT(slotResult(KIO::Job *)));
+ connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
+ TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
+ connect(job, TQT_SIGNAL(result(KIO::Job *)),
+ TQT_SLOT(slotResult(KIO::Job *)));
m_state = GE_LISTPHOTOS;
m_job = job;
@@ -148,10 +148,10 @@ void GalleryTalker::listPhotos( const QString& albumName )
emit signalBusy( true );
}
-void GalleryTalker::createAlbum( const QString& parentAlbumName,
- const QString& albumName,
- const QString& albumTitle,
- const QString& albumCaption )
+void GalleryTalker::createAlbum( const TQString& tqparentAlbumName,
+ const TQString& albumName,
+ const TQString& albumTitle,
+ const TQString& albumCaption )
{
if (m_job)
{
@@ -163,7 +163,7 @@ void GalleryTalker::createAlbum( const QString& parentAlbumName,
form.addPair("cmd", "new-album");
form.addPair("protocol_version", "2.11");
- form.addPair("set_albumName", parentAlbumName);
+ form.addPair("set_albumName", tqparentAlbumName);
if (!albumName.isEmpty())
form.addPair("newAlbumName", albumName);
if (!albumTitle.isEmpty())
@@ -176,10 +176,10 @@ void GalleryTalker::createAlbum( const QString& parentAlbumName,
job->addMetaData("content-type", form.contentType() );
job->addMetaData("cookies", "manual");
job->addMetaData("setcookies", m_cookie);
- connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
- SLOT(data(KIO::Job*, const QByteArray&)));
- connect(job, SIGNAL(result(KIO::Job *)),
- SLOT(slotResult(KIO::Job *)));
+ connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
+ TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
+ connect(job, TQT_SIGNAL(result(KIO::Job *)),
+ TQT_SLOT(slotResult(KIO::Job *)));
m_state = GE_CREATEALBUM;
m_job = job;
@@ -187,9 +187,9 @@ void GalleryTalker::createAlbum( const QString& parentAlbumName,
emit signalBusy( true );
}
-bool GalleryTalker::addPhoto( const QString& albumName,
- const QString& photoPath,
- const QString& caption,
+bool GalleryTalker::addPhoto( const TQString& albumName,
+ const TQString& photoPath,
+ const TQString& caption,
bool captionIsTitle, bool captionIsDescription,
bool rescale, int maxDim )
{
@@ -199,8 +199,8 @@ bool GalleryTalker::addPhoto( const QString& albumName,
m_job = 0;
}
- QString path = photoPath;
- QString display_filename = QFile::encodeName(KURL(path).filename());
+ TQString path = photoPath;
+ TQString display_filename = TQFile::encodeName(KURL(path).filename());
GalleryMPForm form;
@@ -215,18 +215,18 @@ bool GalleryTalker::addPhoto( const QString& albumName,
if (captionIsDescription)
form.addPair("extrafield.Description", caption);
}
- QImage image(photoPath);
+ TQImage image(photoPath);
if (!image.isNull())
{
// image file - see if we need to rescale it
if (rescale && (image.width() > maxDim || image.height() > maxDim))
{
- image = image.smoothScale(maxDim, maxDim, QImage::ScaleMin);
+ image = image.smoothScale(maxDim, maxDim, TQ_ScaleMin);
path = locateLocal("tmp", KURL(photoPath).filename());
- image.save(path, QImageIO::imageFormat(photoPath));
+ image.save(path, TQImageIO::imageFormat(photoPath));
- if ("JPEG" == QString(QImageIO::imageFormat(photoPath)).upper())
+ if ("JPEG" == TQString(TQImageIO::imageFormat(photoPath)).upper())
{
KExiv2Iface::KExiv2 exiv2;
if (exiv2.load(photoPath))
@@ -251,10 +251,10 @@ bool GalleryTalker::addPhoto( const QString& albumName,
job->addMetaData("content-type", form.contentType());
job->addMetaData("cookies", "manual");
job->addMetaData("setcookies", m_cookie);
- connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
- SLOT(data(KIO::Job*, const QByteArray&)));
- connect(job, SIGNAL(result(KIO::Job *)),
- SLOT(slotResult(KIO::Job *)));
+ connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
+ TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
+ connect(job, TQT_SIGNAL(result(KIO::Job *)),
+ TQT_SLOT(slotResult(KIO::Job *)));
m_state = GE_ADDPHOTO;
m_job = job;
@@ -273,7 +273,7 @@ void GalleryTalker::cancel()
}
}
-void GalleryTalker::data(KIO::Job*, const QByteArray& data)
+void GalleryTalker::data(KIO::Job*, const TQByteArray& data)
{
if (data.isEmpty())
return;
@@ -320,11 +320,11 @@ void GalleryTalker::slotResult(KIO::Job *job)
if (m_state == GE_LOGIN && m_loggedIn)
{
- QStringList cookielist = QStringList::split("\n", job->queryMetaData("setcookies"));
+ TQStringList cookielist = TQStringList::split("\n", job->queryMetaData("setcookies"));
m_cookie = "Cookie:";
- for (QStringList::Iterator it = cookielist.begin(); it != cookielist.end(); ++it)
+ for (TQStringList::Iterator it = cookielist.begin(); it != cookielist.end(); ++it)
{
- QRegExp rx("^Set-Cookie: ([^;]+=[^;]+)");
+ TQRegExp rx("^Set-Cookie: ([^;]+=[^;]+)");
if (rx.search(*it) > -1)
m_cookie += " " + rx.cap(1) + ";";
}
@@ -332,11 +332,11 @@ void GalleryTalker::slotResult(KIO::Job *job)
}
}
-void GalleryTalker::parseResponseLogin(const QByteArray &data)
+void GalleryTalker::parseResponseLogin(const TQByteArray &data)
{
- QTextStream ts(data, IO_ReadOnly );
- ts.setEncoding(QTextStream::UnicodeUTF8);
- QString line;
+ TQTextStream ts(data, IO_ReadOnly );
+ ts.setEncoding(TQTextStream::UnicodeUTF8);
+ TQString line;
bool foundResponse = false;
m_loggedIn = false;
@@ -351,7 +351,7 @@ void GalleryTalker::parseResponseLogin(const QByteArray &data)
}
else
{
- QStringList strlist = QStringList::split("=", line);
+ TQStringList strlist = TQStringList::split("=", line);
if (strlist.count() == 2)
{
if (("status" == strlist[0]) && ("0" == strlist[1]))
@@ -378,15 +378,15 @@ void GalleryTalker::parseResponseLogin(const QByteArray &data)
}
}
-void GalleryTalker::parseResponseListAlbums(const QByteArray &data)
+void GalleryTalker::parseResponseListAlbums(const TQByteArray &data)
{
- QTextStream ts(data, IO_ReadOnly );
- ts.setEncoding(QTextStream::UnicodeUTF8);
- QString line;
+ TQTextStream ts(data, IO_ReadOnly );
+ ts.setEncoding(TQTextStream::UnicodeUTF8);
+ TQString line;
bool foundResponse = false;
bool success = false;
- typedef QValueList<GAlbum> GAlbumList;
+ typedef TQValueList<GAlbum> GAlbumList;
GAlbumList albumList;
GAlbumList::iterator iter = albumList.begin();
@@ -399,11 +399,11 @@ void GalleryTalker::parseResponseListAlbums(const QByteArray &data)
}
else
{
- QStringList strlist = QStringList::split("=", line);
+ TQStringList strlist = TQStringList::split("=", line);
if (strlist.count() == 2)
{
- QString key = strlist[0];
- QString value = strlist[1];
+ TQString key = strlist[0];
+ TQString value = strlist[1];
if (key == "status")
{
@@ -429,10 +429,10 @@ void GalleryTalker::parseResponseListAlbums(const QByteArray &data)
if (iter != albumList.end())
(*iter).summary = value;
}
- else if (key.startsWith("album.parent"))
+ else if (key.startsWith("album.tqparent"))
{
if (iter != albumList.end())
- (*iter).parent_ref_num = value.toInt();
+ (*iter).tqparent_ref_num = value.toInt();
}
else if (key.startsWith("album.perms.add"))
{
@@ -479,25 +479,25 @@ void GalleryTalker::parseResponseListAlbums(const QByteArray &data)
return;
}
- // We need parent albums to come first for rest of the code to work
+ // We need tqparent albums to come first for rest of the code to work
qHeapSort(albumList);
emit signalAlbums( albumList );
}
-void GalleryTalker::parseResponseListPhotos(const QByteArray &data)
+void GalleryTalker::parseResponseListPhotos(const TQByteArray &data)
{
- QTextStream ts(data, IO_ReadOnly );
- ts.setEncoding(QTextStream::UnicodeUTF8);
- QString line;
+ TQTextStream ts(data, IO_ReadOnly );
+ ts.setEncoding(TQTextStream::UnicodeUTF8);
+ TQString line;
bool foundResponse = false;
bool success = false;
- typedef QValueList<GPhoto> GPhotoList;
+ typedef TQValueList<GPhoto> GPhotoList;
GPhotoList photoList;
GPhotoList::iterator iter = photoList.begin();
- QString albumURL;
+ TQString albumURL;
while (!ts.atEnd())
{
@@ -509,13 +509,13 @@ void GalleryTalker::parseResponseListPhotos(const QByteArray &data)
}
else
{
- // Boris the Gallery default URL contains "=" char. So we will split the string only from the first "=" char
- QStringList strlist = QStringList();
- strlist << line.left(line.find('=')) << line.mid(line.find('=')+1);
+ // Boris the Gallery default URL tqcontains "=" char. So we will split the string only from the first "=" char
+ TQStringList strlist = TQStringList();
+ strlist << line.left(line.tqfind('=')) << line.mid(line.tqfind('=')+1);
if (strlist.count() >= 2)
{
- QString key = strlist[0];
- QString value = strlist[1];
+ TQString key = strlist[0];
+ TQString value = strlist[1];
if (key == "status")
{
@@ -540,7 +540,7 @@ void GalleryTalker::parseResponseListPhotos(const QByteArray &data)
}
else if (key.startsWith("baseurl"))
{
- albumURL = value.replace("\\","");
+ albumURL = value.tqreplace("\\","");
}
}
}
@@ -566,11 +566,11 @@ void GalleryTalker::parseResponseListPhotos(const QByteArray &data)
emit signalPhotos( photoList );
}
-void GalleryTalker::parseResponseCreateAlbum(const QByteArray &data)
+void GalleryTalker::parseResponseCreateAlbum(const TQByteArray &data)
{
- QTextStream ts(data, IO_ReadOnly );
- ts.setEncoding(QTextStream::UnicodeUTF8);
- QString line;
+ TQTextStream ts(data, IO_ReadOnly );
+ ts.setEncoding(TQTextStream::UnicodeUTF8);
+ TQString line;
bool foundResponse = false;
bool success = false;
@@ -584,11 +584,11 @@ void GalleryTalker::parseResponseCreateAlbum(const QByteArray &data)
}
else
{
- QStringList strlist = QStringList::split("=", line);
+ TQStringList strlist = TQStringList::split("=", line);
if (strlist.count() == 2)
{
- QString key = strlist[0];
- QString value = strlist[1];
+ TQString key = strlist[0];
+ TQString value = strlist[1];
if (key == "status")
{
@@ -618,11 +618,11 @@ void GalleryTalker::parseResponseCreateAlbum(const QByteArray &data)
listAlbums();
}
-void GalleryTalker::parseResponseAddPhoto(const QByteArray &data)
+void GalleryTalker::parseResponseAddPhoto(const TQByteArray &data)
{
- QTextStream ts(data, IO_ReadOnly );
- ts.setEncoding(QTextStream::UnicodeUTF8);
- QString line;
+ TQTextStream ts(data, IO_ReadOnly );
+ ts.setEncoding(TQTextStream::UnicodeUTF8);
+ TQString line;
bool foundResponse = false;
bool success = false;
@@ -640,11 +640,11 @@ void GalleryTalker::parseResponseAddPhoto(const QByteArray &data)
}
else
{
- QStringList strlist = QStringList::split("=", line);
+ TQStringList strlist = TQStringList::split("=", line);
if (strlist.count() == 2)
{
- QString key = strlist[0];
- QString value = strlist[1];
+ TQString key = strlist[0];
+ TQString value = strlist[1];
if (key == "status")
{
diff --git a/kipi-plugins/galleryexport/gallerytalker.h b/kipi-plugins/galleryexport/gallerytalker.h
index 5e5891d..d3a4c41 100644
--- a/kipi-plugins/galleryexport/gallerytalker.h
+++ b/kipi-plugins/galleryexport/gallerytalker.h
@@ -19,7 +19,7 @@
#ifndef GALLERYTALKER_H
#define GALLERYTALKER_H
-#include <qobject.h>
+#include <tqobject.h>
#include <kurl.h>
namespace KIO
@@ -28,7 +28,7 @@ namespace KIO
}
class KURL;
-template <class T> class QValueList;
+template <class T> class TQValueList;
namespace KIPIGalleryExportPlugin
{
@@ -36,9 +36,10 @@ namespace KIPIGalleryExportPlugin
class GAlbum;
class GPhoto;
-class GalleryTalker : public QObject
+class GalleryTalker : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -50,27 +51,27 @@ public:
GE_ADDPHOTO
};
- GalleryTalker(QWidget* parent);
+ GalleryTalker(TQWidget* tqparent);
~GalleryTalker();
static void setGallery2(bool usegallery2) {s_using_gallery2 = usegallery2;};
static bool isGallery2() {return s_using_gallery2;};
- static QString getAuthToken() {return s_authToken;};
+ static TQString getAuthToken() {return s_authToken;};
bool loggedIn() const;
- void login( const KURL& url, const QString& name,
- const QString& passwd );
+ void login( const KURL& url, const TQString& name,
+ const TQString& passwd );
void listAlbums();
- void listPhotos( const QString& albumName );
- void createAlbum( const QString& parentAlbumName,
- const QString& albumName,
- const QString& albumTitle,
- const QString& albumCaption );
- bool addPhoto( const QString& albumName,
- const QString& photoPath,
- const QString& caption=QString(),
+ void listPhotos( const TQString& albumName );
+ void createAlbum( const TQString& tqparentAlbumName,
+ const TQString& albumName,
+ const TQString& albumTitle,
+ const TQString& albumCaption );
+ bool addPhoto( const TQString& albumName,
+ const TQString& photoPath,
+ const TQString& caption=TQString(),
bool captionIsTitle=true, bool captionIsDescription=false,
bool rescale=false, int maxDim=600);
@@ -78,38 +79,38 @@ public:
private:
- QWidget* m_parent;
+ TQWidget* m_parent;
State m_state;
- QString m_cookie;
+ TQString m_cookie;
KURL m_url;
KIO::Job* m_job;
bool m_loggedIn;
- QByteArray m_buffer;
+ TQByteArray m_buffer;
static bool s_using_gallery2;
- static QString s_authToken;
+ static TQString s_authToken;
private:
- void parseResponseLogin(const QByteArray &data);
- void parseResponseListAlbums(const QByteArray &data);
- void parseResponseListPhotos(const QByteArray &data);
- void parseResponseCreateAlbum(const QByteArray &data);
- void parseResponseAddPhoto(const QByteArray &data);
+ void parseResponseLogin(const TQByteArray &data);
+ void parseResponseListAlbums(const TQByteArray &data);
+ void parseResponseListPhotos(const TQByteArray &data);
+ void parseResponseCreateAlbum(const TQByteArray &data);
+ void parseResponseAddPhoto(const TQByteArray &data);
signals:
- void signalError( const QString& msg );
- void signalLoginFailed( const QString& msg );
+ void signalError( const TQString& msg );
+ void signalLoginFailed( const TQString& msg );
void signalBusy( bool val );
- void signalAlbums( const QValueList<GAlbum>& albumList );
- void signalPhotos( const QValueList<GPhoto>& photoList );
+ void signalAlbums( const TQValueList<GAlbum>& albumList );
+ void signalPhotos( const TQValueList<GPhoto>& photoList );
void signalAddPhotoSucceeded( );
- void signalAddPhotoFailed( const QString& msg );
+ void signalAddPhotoFailed( const TQString& msg );
private slots:
- void data(KIO::Job *job, const QByteArray &data);
+ void data(KIO::Job *job, const TQByteArray &data);
void slotResult (KIO::Job *job);
};
diff --git a/kipi-plugins/galleryexport/galleryviewitem.cpp b/kipi-plugins/galleryexport/galleryviewitem.cpp
index 4a847ca..35ab07f 100644
--- a/kipi-plugins/galleryexport/galleryviewitem.cpp
+++ b/kipi-plugins/galleryexport/galleryviewitem.cpp
@@ -19,8 +19,8 @@
*
* ============================================================ */
-#include <qpainter.h>
-#include <qpixmap.h>
+#include <tqpainter.h>
+#include <tqpixmap.h>
#include "galleryviewitem.h"
#include "gallerytalker.h"
@@ -28,23 +28,23 @@
namespace KIPIGalleryExportPlugin
{
-void GAlbumViewItem::paintCell(QPainter * p, const QColorGroup & cg,
+void GAlbumViewItem::paintCell(TQPainter * p, const TQColorGroup & cg,
int column, int width, int )
{
if (!p)
return;
- QListView *lv = listView();
+ TQListView *lv = listView();
if (!lv)
return;
- QFontMetrics fm(p->fontMetrics());
+ TQFontMetrics fm(p->fontMetrics());
if (isSelected())
p->fillRect(0, 0, width, height(), cg.highlight());
else
p->fillRect(0, 0, width, height(), cg.base());
- const QPixmap * icon = pixmap( column );
+ const TQPixmap * icon = pixmap( column );
int iconWidth = 0;
if (icon)
@@ -68,18 +68,18 @@ void GAlbumViewItem::paintCell(QPainter * p, const QColorGroup & cg,
// We display things slightly differently depending on version.
if (GalleryTalker::isGallery2())
{
- p->drawText(r, h/2, width-r, h, Qt::AlignVCenter, album.title);
+ p->drawText(r, h/2, width-r, h, TQt::AlignVCenter, album.title);
}
else
{
- p->drawText(r, 0, width-r, h, Qt::AlignVCenter, album.title);
+ p->drawText(r, 0, width-r, h, TQt::AlignVCenter, album.title);
- QFont fn(lv->font());
+ TQFont fn(lv->font());
fn.setPointSize(fn.pointSize()-2);
fn.setItalic(true);
p->setFont(fn);
- p->setPen(isSelected() ? cg.highlightedText() : Qt::gray);
- p->drawText(r, h, width-r, h, Qt::AlignVCenter, album.name);
+ p->setPen(isSelected() ? cg.highlightedText() : TQt::gray);
+ p->drawText(r, h, width-r, h, TQt::AlignVCenter, album.name);
}
}
@@ -87,7 +87,7 @@ void GAlbumViewItem::setup()
{
int h = listView()->fontMetrics().height();
int margin = 4;
- setHeight( QMAX(2*h + margin, 32) );
+ setHeight( TQMAX(2*h + margin, 32) );
}
}
diff --git a/kipi-plugins/galleryexport/galleryviewitem.h b/kipi-plugins/galleryexport/galleryviewitem.h
index 6c5077a..6a40c69 100644
--- a/kipi-plugins/galleryexport/galleryviewitem.h
+++ b/kipi-plugins/galleryexport/galleryviewitem.h
@@ -19,30 +19,30 @@
#ifndef GALLERYVIEWITEM_H
#define GALLERYVIEWITEM_H
-#include <qlistview.h>
+#include <tqlistview.h>
#include "galleryitem.h"
namespace KIPIGalleryExportPlugin
{
-class GAlbumViewItem : public QListViewItem
+class GAlbumViewItem : public TQListViewItem
{
public:
- GAlbumViewItem(QListView* parent, const QString& name,
+ GAlbumViewItem(TQListView* tqparent, const TQString& name,
const GAlbum& _album)
- : QListViewItem(parent, name), album(_album) {}
- GAlbumViewItem(QListViewItem* parent, const QString& name,
+ : TQListViewItem(tqparent, name), album(_album) {}
+ GAlbumViewItem(TQListViewItem* tqparent, const TQString& name,
const GAlbum& _album)
- : QListViewItem(parent, name), album(_album) {}
+ : TQListViewItem(tqparent, name), album(_album) {}
GAlbum album;
- void paintCell(QPainter * p, const QColorGroup & cg,
+ void paintCell(TQPainter * p, const TQColorGroup & cg,
int column, int width, int );
- void paintFocus (QPainter*, const QColorGroup&,
- const QRect&) {}
+ void paintFocus (TQPainter*, const TQColorGroup&,
+ const TQRect&) {}
protected:
diff --git a/kipi-plugins/galleryexport/gallerywidget.cpp b/kipi-plugins/galleryexport/gallerywidget.cpp
index e3fcc5c..0dd2435 100644
--- a/kipi-plugins/galleryexport/gallerywidget.cpp
+++ b/kipi-plugins/galleryexport/gallerywidget.cpp
@@ -23,53 +23,53 @@
#include <khtml_part.h>
#include <khtmlview.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qframe.h>
-#include <qheader.h>
-#include <qlistview.h>
-#include <qbuttongroup.h>
-#include <qgroupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qsplitter.h>
-#include <qwhatsthis.h>
+#include <tqpushbutton.h>
+#include <tqlabel.h>
+#include <tqframe.h>
+#include <tqheader.h>
+#include <tqlistview.h>
+#include <tqbuttongroup.h>
+#include <tqgroupbox.h>
+#include <tqspinbox.h>
+#include <tqcheckbox.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqsplitter.h>
+#include <tqwhatsthis.h>
#include "gallerywidget.h"
namespace KIPIGalleryExportPlugin
{
-GalleryWidget::GalleryWidget( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+GalleryWidget::GalleryWidget( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "GalleryWidget" );
- QVBoxLayout* galleryWidgetLayout
- = new QVBoxLayout( this, 5, 5, "GalleryWidgetLayout");
+ TQVBoxLayout* galleryWidgetLayout
+ = new TQVBoxLayout( this, 5, 5, "GalleryWidgetLayout");
// ------------------------------------------------------------------------
- QLabel* headerLabel;
- QFrame* headerLine;
+ TQLabel* headerLabel;
+ TQFrame* headerLine;
- headerLabel = new QLabel( this, "headerLabel" );
+ headerLabel = new TQLabel( this, "headerLabel" );
galleryWidgetLayout->addWidget( headerLabel, 0 );
- headerLine = new QFrame( this, "headerLine" );
- headerLine->setFrameShape( QFrame::HLine );
- headerLine->setFrameShadow( QFrame::Sunken );
+ headerLine = new TQFrame( this, "headerLine" );
+ headerLine->setFrameShape( TQFrame::HLine );
+ headerLine->setFrameShadow( TQFrame::Sunken );
galleryWidgetLayout->addWidget( headerLine, 0 );
// ------------------------------------------------------------------------
- QSplitter* splitter = new QSplitter(this);
+ TQSplitter* splitter = new TQSplitter(this);
galleryWidgetLayout->addWidget( splitter, 5 );
- m_albumView = new QListView( splitter, "m_albumView" );
+ m_albumView = new TQListView( splitter, "m_albumView" );
m_albumView->addColumn( i18n( "Albums" ) );
- m_albumView->setResizeMode( QListView::AllColumns );
+ m_albumView->setResizeMode( TQListView::AllColumns );
// ------------------------------------------------------------------------
@@ -77,51 +77,51 @@ GalleryWidget::GalleryWidget( QWidget* parent, const char* name, WFlags fl )
// ------------------------------------------------------------------------
- QVBoxLayout* rightButtonGroupLayout;
- QSpacerItem* spacer;
- QButtonGroup* rightButtonGroup;
+ TQVBoxLayout* rightButtonGroupLayout;
+ TQSpacerItem* spacer;
+ TQButtonGroup* rightButtonGroup;
- rightButtonGroup = new QButtonGroup( splitter, "rightButtonGroup" );
- rightButtonGroupLayout = new QVBoxLayout( rightButtonGroup );
+ rightButtonGroup = new TQButtonGroup( splitter, "rightButtonGroup" );
+ rightButtonGroupLayout = new TQVBoxLayout( rightButtonGroup );
rightButtonGroupLayout->setSpacing( 5 );
rightButtonGroupLayout->setMargin( 5 );
- m_newAlbumBtn = new QPushButton( rightButtonGroup, "m_newAlbumBtn" );
- m_newAlbumBtn->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
- rightButtonGroupLayout->addWidget( m_newAlbumBtn, 0, Qt::AlignHCenter );
+ m_newAlbumBtn = new TQPushButton( rightButtonGroup, "m_newAlbumBtn" );
+ m_newAlbumBtn->tqsetSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed);
+ rightButtonGroupLayout->addWidget( m_newAlbumBtn, 0, TQt::AlignHCenter );
- m_addPhotoBtn = new QPushButton( rightButtonGroup, "m_addPhotoBtn" );
- m_addPhotoBtn->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
- rightButtonGroupLayout->addWidget( m_addPhotoBtn, 0, Qt::AlignHCenter );
+ m_addPhotoBtn = new TQPushButton( rightButtonGroup, "m_addPhotoBtn" );
+ m_addPhotoBtn->tqsetSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed);
+ rightButtonGroupLayout->addWidget( m_addPhotoBtn, 0, TQt::AlignHCenter );
// ------------------------------------------------------------------------
- QGroupBox* optionsBox = new QGroupBox(i18n("Override Default Options"),
+ TQGroupBox* optionsBox = new TQGroupBox(i18n("Override Default Options"),
rightButtonGroup);
optionsBox->setColumnLayout(0, Qt::Vertical);
- optionsBox->layout()->setSpacing(5);
- optionsBox->layout()->setMargin(5);
- QGridLayout* optionsBoxLayout = new QGridLayout(optionsBox->layout());
+ optionsBox->tqlayout()->setSpacing(5);
+ optionsBox->tqlayout()->setMargin(5);
+ TQGridLayout* optionsBoxLayout = new TQGridLayout(optionsBox->tqlayout());
// ------------------------------------------------------------------------
- m_captTitleCheckBox = new QCheckBox(optionsBox);
+ m_captTitleCheckBox = new TQCheckBox(optionsBox);
m_captTitleCheckBox->setText(i18n("Comment sets Title"));
optionsBoxLayout->addMultiCellWidget(m_captTitleCheckBox, 0, 0, 0, 1);
- m_captDescrCheckBox = new QCheckBox(optionsBox);
+ m_captDescrCheckBox = new TQCheckBox(optionsBox);
m_captDescrCheckBox->setText(i18n("Comment sets Description"));
optionsBoxLayout->addMultiCellWidget(m_captDescrCheckBox, 1, 1, 0, 1);
- m_resizeCheckBox = new QCheckBox(optionsBox);
+ m_resizeCheckBox = new TQCheckBox(optionsBox);
m_resizeCheckBox->setText(i18n("Resize photos before uploading"));
optionsBoxLayout->addMultiCellWidget(m_resizeCheckBox, 2, 2, 0, 1);
- m_dimensionSpinBox = new QSpinBox(0, 5000, 10, optionsBox);
+ m_dimensionSpinBox = new TQSpinBox(0, 5000, 10, optionsBox);
m_dimensionSpinBox->setValue(600);
- m_dimensionSpinBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+ m_dimensionSpinBox->tqsetSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed);
optionsBoxLayout->addWidget(m_dimensionSpinBox, 3, 1);
- QLabel* resizeLabel = new QLabel(i18n("Maximum dimension:"), optionsBox);
+ TQLabel* resizeLabel = new TQLabel(i18n("Maximum dimension:"), optionsBox);
optionsBoxLayout->addWidget(resizeLabel, 3, 0);
m_captTitleCheckBox->setChecked(true);
@@ -129,7 +129,7 @@ GalleryWidget::GalleryWidget( QWidget* parent, const char* name, WFlags fl )
m_resizeCheckBox->setChecked(false);
m_dimensionSpinBox->setEnabled(false);
- connect(m_resizeCheckBox, SIGNAL(clicked()), SLOT(slotResizeChecked()));
+ connect(m_resizeCheckBox, TQT_SIGNAL(clicked()), TQT_SLOT(slotResizeChecked()));
// ------------------------------------------------------------------------
@@ -137,7 +137,7 @@ GalleryWidget::GalleryWidget( QWidget* parent, const char* name, WFlags fl )
// ------------------------------------------------------------------------
- spacer = new QSpacerItem( 20, 100, QSizePolicy::Minimum, QSizePolicy::Expanding );
+ spacer = new TQSpacerItem( 20, 100, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
rightButtonGroupLayout->addItem( spacer );
// ------------------------------------------------------------------------
@@ -149,7 +149,7 @@ GalleryWidget::GalleryWidget( QWidget* parent, const char* name, WFlags fl )
// ------------------------------------------------------------------------
- resize( QSize(600, 400).expandedTo(minimumSizeHint()) );
+ resize( TQSize(600, 400).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
}
diff --git a/kipi-plugins/galleryexport/gallerywidget.h b/kipi-plugins/galleryexport/gallerywidget.h
index 2022856..a14c944 100644
--- a/kipi-plugins/galleryexport/gallerywidget.h
+++ b/kipi-plugins/galleryexport/gallerywidget.h
@@ -19,24 +19,25 @@
#ifndef GALLERYWIDGET_H
#define GALLERYWIDGET_H
-#include <qwidget.h>
+#include <tqwidget.h>
-class QListView;
-class QPushButton;
-class QSpinBox;
-class QCheckBox;
+class TQListView;
+class TQPushButton;
+class TQSpinBox;
+class TQCheckBox;
class KHTMLPart;
namespace KIPIGalleryExportPlugin
{
-class GalleryWidget : public QWidget
+class GalleryWidget : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- GalleryWidget( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
+ GalleryWidget( TQWidget* tqparent = 0, const char* name = 0, WFlags fl = 0 );
~GalleryWidget();
private slots:
@@ -45,14 +46,14 @@ private slots:
private:
- QListView* m_albumView;
+ TQListView* m_albumView;
KHTMLPart* m_photoView;
- QPushButton* m_newAlbumBtn;
- QPushButton* m_addPhotoBtn;
- QCheckBox* m_captTitleCheckBox;
- QCheckBox* m_captDescrCheckBox;
- QCheckBox* m_resizeCheckBox;
- QSpinBox* m_dimensionSpinBox;
+ TQPushButton* m_newAlbumBtn;
+ TQPushButton* m_addPhotoBtn;
+ TQCheckBox* m_captTitleCheckBox;
+ TQCheckBox* m_captDescrCheckBox;
+ TQCheckBox* m_resizeCheckBox;
+ TQSpinBox* m_dimensionSpinBox;
friend class GalleryWindow;
};
diff --git a/kipi-plugins/galleryexport/gallerywindow.cpp b/kipi-plugins/galleryexport/gallerywindow.cpp
index 2dabde2..fb90a36 100644
--- a/kipi-plugins/galleryexport/gallerywindow.cpp
+++ b/kipi-plugins/galleryexport/gallerywindow.cpp
@@ -19,17 +19,17 @@
*
* ============================================================ */
-// Include files for Qt
-
-#include <qlistview.h>
-#include <qpushbutton.h>
-#include <qtimer.h>
-#include <qpixmap.h>
-#include <qcursor.h>
-#include <qlineedit.h>
-#include <qprogressdialog.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
+// Include files for TQt
+
+#include <tqlistview.h>
+#include <tqpushbutton.h>
+#include <tqtimer.h>
+#include <tqpixmap.h>
+#include <tqcursor.h>
+#include <tqlineedit.h>
+#include <tqprogressdialog.h>
+#include <tqspinbox.h>
+#include <tqcheckbox.h>
// Include files for KDE
@@ -68,8 +68,8 @@
namespace KIPIGalleryExportPlugin
{
-GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galleries* pGalleries)
- : KDialogBase(parent, 0, true, i18n("Gallery Export"), Help|Close, Close, false),
+GalleryWindow::GalleryWindow(KIPI::Interface* interface, TQWidget *tqparent, Galleries* pGalleries)
+ : KDialogBase(tqparent, 0, true, i18n("Gallery Export"), Help|Close, Close, false),
m_interface(interface),
mpGalleries(pGalleries)
{
@@ -93,7 +93,7 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galler
m_helpButton = actionButton( Help );
KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
helpMenu->menu()->removeItemAt(0);
- helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+ helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
m_helpButton->setPopup( helpMenu->menu() );
GalleryWidget* widget = new GalleryWidget(this);
@@ -114,40 +114,40 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galler
m_newAlbumBtn->setEnabled( false );
m_addPhotoBtn->setEnabled( false );
- m_progressDlg = new QProgressDialog( this, 0, true );
+ m_progressDlg = new TQProgressDialog( this, 0, true );
m_progressDlg->setAutoReset( true );
m_progressDlg->setAutoClose( true );
- connect(m_progressDlg, SIGNAL(canceled()), SLOT(slotAddPhotoCancel()));
+ connect(m_progressDlg, TQT_SIGNAL(canceled()), TQT_SLOT(slotAddPhotoCancel()));
- connect(m_albumView, SIGNAL(selectionChanged()), SLOT(slotAlbumSelected()));
+ connect(m_albumView, TQT_SIGNAL(selectionChanged()), TQT_SLOT(slotAlbumSelected()));
connect(m_photoView->browserExtension(),
- SIGNAL(openURLRequest(const KURL&,
+ TQT_SIGNAL(openURLRequest(const KURL&,
const KParts::URLArgs&)),
- SLOT(slotOpenPhoto(const KURL&)));
+ TQT_SLOT(slotOpenPhoto(const KURL&)));
- connect(m_newAlbumBtn, SIGNAL(clicked()), SLOT(slotNewAlbum()));
- connect(m_addPhotoBtn, SIGNAL(clicked()), SLOT( slotAddPhotos()));
+ connect(m_newAlbumBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotNewAlbum()));
+ connect(m_addPhotoBtn, TQT_SIGNAL(clicked()), TQT_SLOT( slotAddPhotos()));
// read config
KConfig config("kipirc");
config.setGroup("GallerySync Settings");
m_talker = new GalleryTalker( this );
- connect( m_talker, SIGNAL( signalError( const QString& ) ),
- SLOT( slotError( const QString& ) ) );
- connect( m_talker, SIGNAL( signalBusy( bool ) ),
- SLOT( slotBusy( bool ) ) );
- connect( m_talker, SIGNAL( signalLoginFailed( const QString& ) ),
- SLOT( slotLoginFailed( const QString& ) ) );
- connect( m_talker, SIGNAL( signalAlbums( const QValueList<GAlbum>& ) ),
- SLOT( slotAlbums( const QValueList<GAlbum>& ) ) );
- connect( m_talker, SIGNAL( signalPhotos( const QValueList<GPhoto>& ) ),
- SLOT( slotPhotos( const QValueList<GPhoto>& ) ) );
- connect( m_talker, SIGNAL( signalAddPhotoSucceeded() ),
- SLOT( slotAddPhotoSucceeded() ) );
- connect( m_talker, SIGNAL( signalAddPhotoFailed( const QString& ) ),
- SLOT( slotAddPhotoFailed( const QString& ) ) );
+ connect( m_talker, TQT_SIGNAL( signalError( const TQString& ) ),
+ TQT_SLOT( slotError( const TQString& ) ) );
+ connect( m_talker, TQT_SIGNAL( signalBusy( bool ) ),
+ TQT_SLOT( slotBusy( bool ) ) );
+ connect( m_talker, TQT_SIGNAL( signalLoginFailed( const TQString& ) ),
+ TQT_SLOT( slotLoginFailed( const TQString& ) ) );
+ connect( m_talker, TQT_SIGNAL( signalAlbums( const TQValueList<GAlbum>& ) ),
+ TQT_SLOT( slotAlbums( const TQValueList<GAlbum>& ) ) );
+ connect( m_talker, TQT_SIGNAL( signalPhotos( const TQValueList<GPhoto>& ) ),
+ TQT_SLOT( slotPhotos( const TQValueList<GPhoto>& ) ) );
+ connect( m_talker, TQT_SIGNAL( signalAddPhotoSucceeded() ),
+ TQT_SLOT( slotAddPhotoSucceeded() ) );
+ connect( m_talker, TQT_SIGNAL( signalAddPhotoFailed( const TQString& ) ),
+ TQT_SLOT( slotAddPhotoFailed( const TQString& ) ) );
if (config.readBoolEntry("Resize", false))
{
@@ -172,7 +172,7 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galler
m_dimensionSpinBox->setValue(config.readNumEntry("Maximum Width", 1600));
- QTimer::singleShot( 0, this, SLOT( slotDoLogin() ) );
+ TQTimer::singleShot( 0, this, TQT_SLOT( slotDoLogin() ) );
}
GalleryWindow::~GalleryWindow()
@@ -199,7 +199,7 @@ void GalleryWindow::slotDoLogin()
{
GalleryList dlg(this, mpGalleries);
- if (QDialog::Accepted != dlg.exec())
+ if (TQDialog::Accepted != dlg.exec())
{
close();
return;
@@ -237,7 +237,7 @@ void GalleryWindow::slotDoLogin()
m_talker->login(url.url(), p_gallery->username(), p_gallery->password());
}
-void GalleryWindow::slotLoginFailed( const QString& msg )
+void GalleryWindow::slotLoginFailed( const TQString& msg )
{
if ( KMessageBox::warningYesNo( this,
i18n( "Failed to login into remote gallery. " )
@@ -256,25 +256,25 @@ void GalleryWindow::slotBusy( bool val )
{
if ( val )
{
- setCursor(QCursor::WaitCursor);
+ setCursor(TQCursor::WaitCursor);
m_newAlbumBtn->setEnabled( false );
m_addPhotoBtn->setEnabled( false );
}
else
{
- setCursor(QCursor::ArrowCursor);
+ setCursor(TQCursor::ArrowCursor);
bool loggedIn = m_talker->loggedIn();
m_newAlbumBtn->setEnabled( loggedIn );
m_addPhotoBtn->setEnabled( loggedIn && m_albumView->selectedItem() );
}
}
-void GalleryWindow::slotError( const QString& msg )
+void GalleryWindow::slotError( const TQString& msg )
{
KMessageBox::error( this, msg );
}
-void GalleryWindow::slotAlbums( const QValueList<GAlbum>& albumList )
+void GalleryWindow::slotAlbums( const TQValueList<GAlbum>& albumList )
{
m_albumDict.clear();
m_albumView->clear();
@@ -283,15 +283,15 @@ void GalleryWindow::slotAlbums( const QValueList<GAlbum>& albumList )
m_photoView->end();
KIconLoader* iconLoader = KApplication::kApplication()->iconLoader();
- QPixmap pix = iconLoader->loadIcon( "folder", KIcon::NoGroup, 32 );
+ TQPixmap pix = iconLoader->loadIcon( "folder", KIcon::NoGroup, 32 );
- typedef QValueList<GAlbum> GAlbumList;
+ typedef TQValueList<GAlbum> GAlbumList;
GAlbumList::const_iterator iter;
for ( iter = albumList.begin(); iter != albumList.end(); ++iter )
{
const GAlbum& album = *iter;
- if ( album.parent_ref_num == 0 )
+ if ( album.tqparent_ref_num == 0 )
{
GAlbumViewItem* item = new GAlbumViewItem( m_albumView, album.title,
album );
@@ -300,17 +300,17 @@ void GalleryWindow::slotAlbums( const QValueList<GAlbum>& albumList )
}
else
{
- QListViewItem* parent = m_albumDict.find( album.parent_ref_num );
- if ( parent )
+ TQListViewItem* tqparent = m_albumDict.tqfind( album.tqparent_ref_num );
+ if ( tqparent )
{
- GAlbumViewItem* item = new GAlbumViewItem( parent, album.title,
+ GAlbumViewItem* item = new GAlbumViewItem( tqparent, album.title,
album);
item->setPixmap( 0, pix );
m_albumDict.insert( album.ref_num, item );
}
else
{
- kdWarning() << "Failed to find parent for album "
+ kdWarning() << "Failed to find tqparent for album "
<< album.name
<< " with id " << album.ref_num << "\n";
}
@@ -331,7 +331,7 @@ void GalleryWindow::slotAlbums( const QValueList<GAlbum>& albumList )
if (lastSelectedID > 0)
{
- GAlbumViewItem* lastSelectedItem = m_albumDict.find( lastSelectedID );
+ GAlbumViewItem* lastSelectedItem = m_albumDict.tqfind( lastSelectedID );
if (lastSelectedItem)
{
m_albumView->setSelected( lastSelectedItem, true );
@@ -340,24 +340,24 @@ void GalleryWindow::slotAlbums( const QValueList<GAlbum>& albumList )
}
}
-void GalleryWindow::slotPhotos( const QValueList<GPhoto>& photoList)
+void GalleryWindow::slotPhotos( const TQValueList<GPhoto>& photoList)
{
int pxSize = fontMetrics().height() - 2;
- QString styleSheet =
- QString( "body { margin: 8px; font-size: %1px; "
+ TQString styleSheet =
+ TQString( "body { margin: 8px; font-size: %1px; "
" color: %2; background-color: %3;}" )
- .arg( pxSize )
- .arg( colorGroup().text().name() )
- .arg( colorGroup().base().name() );
+ .tqarg( pxSize )
+ .tqarg( tqcolorGroup().text().name() )
+ .tqarg( tqcolorGroup().base().name() );
- styleSheet += QString( "a { font-size: %1px; color: %2; "
+ styleSheet += TQString( "a { font-size: %1px; color: %2; "
"text-decoration: none;}" )
- .arg( pxSize )
- .arg( colorGroup().text().name() );
- styleSheet += QString( "i { font-size: %1px; color: %2; "
+ .tqarg( pxSize )
+ .tqarg( tqcolorGroup().text().name() );
+ styleSheet += TQString( "i { font-size: %1px; color: %2; "
"text-decoration: none;}" )
- .arg( pxSize-2 )
- .arg( QColor("steelblue").name() );
+ .tqarg( pxSize-2 )
+ .tqarg( TQColor("steelblue").name() );
m_photoView->begin();
m_photoView->setUserStyleSheet( styleSheet );
@@ -368,7 +368,7 @@ void GalleryWindow::slotPhotos( const QValueList<GPhoto>& photoList)
"border='0' cellspacing='1' cellpadding='1'>" );
- typedef QValueList<GPhoto> GPhotoList;
+ typedef TQValueList<GPhoto> GPhotoList;
GPhotoList::const_iterator iter;
for ( iter = photoList.begin(); iter != photoList.end(); ++iter )
{
@@ -377,14 +377,14 @@ void GalleryWindow::slotPhotos( const QValueList<GPhoto>& photoList)
KURL thumburl(photo.albumURL + photo.thumbName);
m_photoView->write( "<tr><td class='photo'>"
- + QString("<a href='%1'>")
- .arg(imageurl.url())
- + QString("<img border=1 src=\"%1\"><br>")
- .arg(thumburl.url())
+ + TQString("<a href='%1'>")
+ .tqarg(imageurl.url())
+ + TQString("<img border=1 src=\"%1\"><br>")
+ .tqarg(thumburl.url())
+ photo.name
- + ( photo.caption.isEmpty() ? QString() :
- QString("<br><i>%1</i>")
- .arg(photo.caption) )
+ + ( photo.caption.isEmpty() ? TQString() :
+ TQString("<br><i>%1</i>")
+ .tqarg(photo.caption) )
+ "</a></td></tr>" );
}
@@ -396,7 +396,7 @@ void GalleryWindow::slotPhotos( const QValueList<GPhoto>& photoList)
void GalleryWindow::slotAlbumSelected()
{
- QListViewItem* item = m_albumView->selectedItem();
+ TQListViewItem* item = m_albumView->selectedItem();
if ( !item )
{
m_addPhotoBtn->setEnabled( false );
@@ -427,19 +427,19 @@ void GalleryWindow::slotNewAlbum()
{
GalleryAlbumDialog dlg;
dlg.titleEdit->setFocus( );
- if ( dlg.exec() != QDialog::Accepted )
+ if ( dlg.exec() != TQDialog::Accepted )
{
return;
}
- QString name = dlg.nameEdit->text();
- QString title = dlg.titleEdit->text();
- QString caption = dlg.captionEdit->text();
+ TQString name = dlg.nameEdit->text();
+ TQString title = dlg.titleEdit->text();
+ TQString caption = dlg.captionEdit->text();
// check for prohibited chars in the album name
// \ / * ? " ' & < > | . + # ( ) or spaces
- // Todo: Change this to a QRegExp check.
- QChar ch;
+ // Todo: Change this to a TQRegExp check.
+ TQChar ch;
bool clean = true;
for (uint i=0; i<name.length(); i++)
{
@@ -529,29 +529,29 @@ void GalleryWindow::slotNewAlbum()
if (!clean)
{
KMessageBox::error( this, i18n("Sorry, these characters are not allowed in album name: %1")
- .arg("\\ / * ? \" \' & < > | . + # ( ) or spaces") );
+ .tqarg("\\ / * ? \" \' & < > | . + # ( ) or spaces") );
return;
}
- QString parentAlbumName;
+ TQString tqparentAlbumName;
- QListViewItem* item = m_albumView->selectedItem();
+ TQListViewItem* item = m_albumView->selectedItem();
if (item)
{
GAlbumViewItem* viewItem = static_cast<GAlbumViewItem*>(item);
- parentAlbumName = viewItem->album.name;
+ tqparentAlbumName = viewItem->album.name;
}
else
{
- parentAlbumName = "0";
+ tqparentAlbumName = "0";
}
- m_talker->createAlbum(parentAlbumName, name, title, caption);
+ m_talker->createAlbum(tqparentAlbumName, name, title, caption);
}
void GalleryWindow::slotAddPhotos()
{
- QListViewItem* item = m_albumView->selectedItem();
+ TQListViewItem* item = m_albumView->selectedItem();
if (!item)
return;
@@ -559,7 +559,7 @@ void GalleryWindow::slotAddPhotos()
if (urls.isEmpty())
return;
- typedef QPair<QString,QString> Pair;
+ typedef TQPair<TQString,TQString> Pair;
m_uploadQueue.clear();
for (KURL::List::iterator it = urls.begin(); it != urls.end(); ++it)
@@ -584,7 +584,7 @@ void GalleryWindow::slotAddPhotoNext()
return;
}
- typedef QPair<QString,QString> Pair;
+ typedef TQPair<TQString,TQString> Pair;
Pair pathComments = m_uploadQueue.first();
m_uploadQueue.pop_front();
@@ -601,7 +601,7 @@ void GalleryWindow::slotAddPhotoNext()
}
m_progressDlg->setLabelText( i18n("Uploading file %1 ")
- .arg( KURL(pathComments.first).filename() ) );
+ .tqarg( KURL(pathComments.first).filename() ) );
if (m_progressDlg->isHidden())
m_progressDlg->show();
@@ -614,7 +614,7 @@ void GalleryWindow::slotAddPhotoSucceeded()
slotAddPhotoNext();
}
-void GalleryWindow::slotAddPhotoFailed( const QString& msg )
+void GalleryWindow::slotAddPhotoFailed( const TQString& msg )
{
if ( KMessageBox::warningContinueCancel( this,
i18n( "Failed to upload photo into "
diff --git a/kipi-plugins/galleryexport/gallerywindow.h b/kipi-plugins/galleryexport/gallerywindow.h
index 3d160e0..07cd366 100644
--- a/kipi-plugins/galleryexport/gallerywindow.h
+++ b/kipi-plugins/galleryexport/gallerywindow.h
@@ -20,15 +20,15 @@
#define GALLERYWINDOW_H
#include <kdialogbase.h>
-#include <qvaluelist.h>
-#include <qpair.h>
-#include <qintdict.h>
-
-class QListView;
-class QPushButton;
-class QSpinBox;
-class QCheckBox;
-class QProgressDialog;
+#include <tqvaluelist.h>
+#include <tqpair.h>
+#include <tqintdict.h>
+
+class TQListView;
+class TQPushButton;
+class TQSpinBox;
+class TQCheckBox;
+class TQProgressDialog;
class KHTMLPart;
class KURL;
@@ -53,33 +53,34 @@ class GAlbumViewItem;
class GalleryWindow : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- GalleryWindow(KIPI::Interface *interface, QWidget *parent, Galleries* pGalleries);
+ GalleryWindow(KIPI::Interface *interface, TQWidget *tqparent, Galleries* pGalleries);
~GalleryWindow();
private:
- QListView *m_albumView;
+ TQListView *m_albumView;
KHTMLPart *m_photoView;
- QPushButton *m_newAlbumBtn;
- QPushButton *m_addPhotoBtn;
- QPushButton *m_helpButton;
- QCheckBox *m_captTitleCheckBox;
- QCheckBox *m_captDescrCheckBox;
- QCheckBox *m_resizeCheckBox;
- QSpinBox *m_dimensionSpinBox;
+ TQPushButton *m_newAlbumBtn;
+ TQPushButton *m_addPhotoBtn;
+ TQPushButton *m_helpButton;
+ TQCheckBox *m_captTitleCheckBox;
+ TQCheckBox *m_captDescrCheckBox;
+ TQCheckBox *m_resizeCheckBox;
+ TQSpinBox *m_dimensionSpinBox;
GalleryTalker *m_talker;
- QIntDict<GAlbumViewItem> m_albumDict;
- QString m_lastSelectedAlbum;
+ TQIntDict<GAlbumViewItem> m_albumDict;
+ TQString m_lastSelectedAlbum;
KIPI::Interface *m_interface;
KIPIPlugins::KPAboutData *m_about;
- QProgressDialog *m_progressDlg;
+ TQProgressDialog *m_progressDlg;
unsigned int m_uploadCount;
unsigned int m_uploadTotal;
- QValueList< QPair<QString,QString> > m_uploadQueue;
+ TQValueList< TQPair<TQString,TQString> > m_uploadQueue;
Galleries* mpGalleries;
Gallery* mpGallery;
@@ -87,18 +88,18 @@ private:
private slots:
void slotDoLogin();
- void slotLoginFailed( const QString& msg );
+ void slotLoginFailed( const TQString& msg );
void slotBusy( bool val );
- void slotError( const QString& msg );
- void slotAlbums( const QValueList<GAlbum>& albumList );
- void slotPhotos( const QValueList<GPhoto>& photoList );
+ void slotError( const TQString& msg );
+ void slotAlbums( const TQValueList<GAlbum>& albumList );
+ void slotPhotos( const TQValueList<GPhoto>& photoList );
void slotAlbumSelected();
void slotOpenPhoto( const KURL& url );
void slotNewAlbum();
void slotAddPhotos();
void slotAddPhotoNext();
void slotAddPhotoSucceeded();
- void slotAddPhotoFailed( const QString& msg );
+ void slotAddPhotoFailed( const TQString& msg );
void slotAddPhotoCancel();
void slotHelp();
};
diff --git a/kipi-plugins/galleryexport/plugin_galleryexport.cpp b/kipi-plugins/galleryexport/plugin_galleryexport.cpp
index 032fea9..9753a92 100644
--- a/kipi-plugins/galleryexport/plugin_galleryexport.cpp
+++ b/kipi-plugins/galleryexport/plugin_galleryexport.cpp
@@ -47,23 +47,23 @@ typedef KGenericFactory<Plugin_GalleryExport> Factory;
K_EXPORT_COMPONENT_FACTORY(kipiplugin_galleryexport,
Factory("kipiplugin_galleryexport"))
-Plugin_GalleryExport::Plugin_GalleryExport(QObject *parent,
+Plugin_GalleryExport::Plugin_GalleryExport(TQObject *tqparent,
const char*,
- const QStringList&)
- : KIPI::Plugin(Factory::instance(), parent, "GalleryExport"),
+ const TQStringList&)
+ : KIPI::Plugin(Factory::instance(), tqparent, "GalleryExport"),
mpGalleries(0)
{
kdDebug(51001) << "Plugin_GalleryExport plugin loaded"
<< endl;
}
-void Plugin_GalleryExport::setup(QWidget* widget)
+void Plugin_GalleryExport::setup(TQWidget* widget)
{
mpGalleries = new KIPIGalleryExportPlugin::Galleries();
KIPI::Plugin::setup(widget);
- KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
+ KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(tqparent());
if (!interface)
{
@@ -77,7 +77,7 @@ void Plugin_GalleryExport::setup(QWidget* widget)
m_action_sync = new KAction(i18n("Remote Gallery Sync..."),
0,
this,
- SLOT(slotSync()),
+ TQT_SLOT(slotSync()),
actionCollection(),
"galleryexport");
m_action_sync->setEnabled(true);
@@ -86,7 +86,7 @@ void Plugin_GalleryExport::setup(QWidget* widget)
m_action_configure = new KAction(i18n("Remote Galleries..."),
0,
this,
- SLOT(slotConfigure()),
+ TQT_SLOT(slotConfigure()),
actionCollection(),
"galleryexport");
m_action_configure->setEnabled(true);
@@ -95,7 +95,7 @@ void Plugin_GalleryExport::setup(QWidget* widget)
m_action_collection_settings = new KAction(i18n("Remote Gallery Settings..."),
0,
this,
- SLOT(slotCollectionSettings()),
+ TQT_SLOT(slotCollectionSettings()),
actionCollection(),
"galleryexport");
m_action_collection_settings->setEnabled(true);
@@ -104,7 +104,7 @@ void Plugin_GalleryExport::setup(QWidget* widget)
m_action_image_setting = new KAction(i18n("Remote Gallery Settings..."),
0,
this,
- SLOT(slotImageSettings()),
+ TQT_SLOT(slotImageSettings()),
actionCollection(),
"galleryexport");
m_action_image_setting->setEnabled(true);
@@ -122,52 +122,52 @@ Plugin_GalleryExport::~Plugin_GalleryExport()
void Plugin_GalleryExport::slotSync()
{
- KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
+ KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(tqparent());
if (!interface)
{
kdError( 51000 ) << "Kipi interface is null!" << endl;
return;
}
- KIPIGalleryExportPlugin::GalleryWindow dlg(interface, kapp->activeWindow(), mpGalleries);
+ KIPIGalleryExportPlugin::GalleryWindow dlg(interface, TQT_TQWIDGET(kapp->activeWindow()), mpGalleries);
dlg.exec();
}
void Plugin_GalleryExport::slotConfigure()
{
- KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
+ KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(tqparent());
if (!interface)
{
kdError( 51000 ) << "Kipi interface is null!" << endl;
return;
}
- KIPIGalleryExportPlugin::GalleryList dlg(kapp->activeWindow(), mpGalleries, false);
+ KIPIGalleryExportPlugin::GalleryList dlg(TQT_TQWIDGET(kapp->activeWindow()), mpGalleries, false);
dlg.exec();
}
void Plugin_GalleryExport::slotCollectionSettings()
{
- KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
+ KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(tqparent());
if (!interface)
{
kdError( 51000 ) << "Kipi interface is null!" << endl;
return;
}
- KMessageBox::error(kapp->activeWindow(), "Not Implemented Yet!");
+ KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), "Not Implemented Yet!");
}
void Plugin_GalleryExport::slotImageSettings()
{
- KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
+ KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(tqparent());
if (!interface)
{
kdError( 51000 ) << "Kipi interface is null!" << endl;
return;
}
- KMessageBox::error(kapp->activeWindow(), "Not Implemented Yet!");
+ KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), "Not Implemented Yet!");
}
KIPI::Category Plugin_GalleryExport::category( KAction* action ) const
diff --git a/kipi-plugins/galleryexport/plugin_galleryexport.h b/kipi-plugins/galleryexport/plugin_galleryexport.h
index b6505dc..a6f61d3 100644
--- a/kipi-plugins/galleryexport/plugin_galleryexport.h
+++ b/kipi-plugins/galleryexport/plugin_galleryexport.h
@@ -36,16 +36,17 @@ class Galleries;
class Plugin_GalleryExport : public KIPI::Plugin
{
Q_OBJECT
+ TQ_OBJECT
public:
- Plugin_GalleryExport(QObject *parent,
+ Plugin_GalleryExport(TQObject *tqparent,
const char* name,
- const QStringList &args);
+ const TQStringList &args);
~Plugin_GalleryExport();
virtual KIPI::Category category( KAction* action ) const;
- virtual void setup( QWidget* );
+ virtual void setup( TQWidget* );
public slots:
diff --git a/kipi-plugins/galleryexport/gallerylist.cpp b/kipi-plugins/galleryexport/gallerylist.cpp
index 36192d5..314ebd2 100644
--- a/kipi-plugins/galleryexport/gallerylist.cpp
+++ b/kipi-plugins/galleryexport/gallerylist.cpp
@@ -17,18 +17,18 @@
*
* ============================================================ */
-// Include files for Qt
-
-#include <qlistview.h>
-#include <qpushbutton.h>
-#include <qtimer.h>
-#include <qpixmap.h>
-#include <qcursor.h>
-#include <qlineedit.h>
-#include <qprogressdialog.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qlayout.h>
+// Include files for TQt
+
+#include <tqlistview.h>
+#include <tqpushbutton.h>
+#include <tqtimer.h>
+#include <tqpixmap.h>
+#include <tqcursor.h>
+#include <tqlineedit.h>
+#include <tqprogressdialog.h>
+#include <tqspinbox.h>
+#include <tqcheckbox.h>
+#include <tqlayout.h>
// Include files for KDE
@@ -46,7 +46,7 @@
namespace KIPIGalleryExportPlugin
{
-GalleryList::GalleryList(QWidget *pParent, Galleries* pGalleries, bool blnShowOpen)
+GalleryList::GalleryList(TQWidget *pParent, Galleries* pGalleries, bool blnShowOpen)
: KDialogBase(pParent, 0, true, i18n("Remote Galleries"),
Ok|Close|User1|User2|User3,
Close, false),
@@ -66,29 +66,29 @@ GalleryList::GalleryList(QWidget *pParent, Galleries* pGalleries, bool blnShowOp
enableButton(User1, false);
enableButton(User2, false);
- QFrame *page = new QFrame(this);
- QHBoxLayout *tll = new QHBoxLayout(page);
+ TQFrame *page = new TQFrame(this);
+ TQHBoxLayout *tll = new TQHBoxLayout(page);
page->setMinimumSize(400, 200);
setMainWidget(page);
- QHBoxLayout *hb = new QHBoxLayout();
+ TQHBoxLayout *hb = new TQHBoxLayout();
hb->setSpacing(KDialog::spacingHint());
tll->addItem(hb);
- QLabel *label = new QLabel(page);
+ TQLabel *label = new TQLabel(page);
hb->addWidget(label);
label->setPixmap(UserIcon("gallery"));
- label->setFrameStyle (QFrame::Panel | QFrame::Sunken);
- label->setAlignment(Qt::AlignTop);
- QVBoxLayout *vb = new QVBoxLayout();
+ label->setFrameStyle (TQFrame::Panel | TQFrame::Sunken);
+ label->tqsetAlignment(TQt::AlignTop);
+ TQVBoxLayout *vb = new TQVBoxLayout();
vb->setSpacing (KDialog::spacingHint());
tll->addItem(vb);
- mpGalleryList = mpGalleries->asQListView(page);
+ mpGalleryList = mpGalleries->asTQListView(page);
vb->addWidget(mpGalleryList);
- connect(mpGalleryList, SIGNAL(selectionChanged()), this, SLOT(selectionChanged()));
- connect(mpGalleryList, SIGNAL(doubleClicked(QListViewItem*, const QPoint&, int)),
- this, SLOT(doubleClicked(QListViewItem*, const QPoint&, int)));
+ connect(mpGalleryList, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(selectionChanged()));
+ connect(mpGalleryList, TQT_SIGNAL(doubleClicked(TQListViewItem*, const TQPoint&, int)),
+ this, TQT_SLOT(doubleClicked(TQListViewItem*, const TQPoint&, int)));
}
GalleryList::~GalleryList()
@@ -103,7 +103,7 @@ Gallery* GalleryList::GetGallery()
void GalleryList::selectionChanged()
{
- QListViewItem* p_lvi = mpGalleryList->selectedItem();
+ TQListViewItem* p_lvi = mpGalleryList->selectedItem();
bool bln_selected = (p_lvi ? true : false);
enableButton(User1, bln_selected);
enableButton(User2, bln_selected);
@@ -111,7 +111,7 @@ void GalleryList::selectionChanged()
if (bln_selected)
{
- GalleryQListViewItem* p_glvi = dynamic_cast<GalleryQListViewItem*>(p_lvi);
+ GalleryTQListViewItem* p_glvi = dynamic_cast<GalleryTQListViewItem*>(p_lvi);
mpCurrentGallery = p_glvi->GetGallery();
}
else
@@ -120,7 +120,7 @@ void GalleryList::selectionChanged()
}
}
-void GalleryList::doubleClicked(QListViewItem* pCurrent, const QPoint&, int)
+void GalleryList::doubleClicked(TQListViewItem* pCurrent, const TQPoint&, int)
{
if (!pCurrent)
return;
@@ -140,11 +140,11 @@ void GalleryList::slotUser3(void)
{
Gallery* p_gallery = new Gallery();
GalleryEdit dlg(this, p_gallery, i18n("New Remote Gallery"));
- if (QDialog::Accepted == dlg.exec())
+ if (TQDialog::Accepted == dlg.exec())
{
mpGalleries->Add(p_gallery);
mpGalleries->Save();
- p_gallery->asQListViewItem(mpGalleryList);
+ p_gallery->asTQListViewItem(mpGalleryList);
}
else
{
@@ -156,16 +156,16 @@ void GalleryList::slotUser3(void)
//================== Edit ======
void GalleryList::slotUser2(void)
{
- QListViewItem* p_lvi = mpGalleryList->selectedItem();
+ TQListViewItem* p_lvi = mpGalleryList->selectedItem();
if (!p_lvi)
{
- KMessageBox::error(kapp->activeWindow(), i18n("No gallery selected!"));
+ KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), i18n("No gallery selected!"));
}
else
{
- GalleryQListViewItem* p_glvi = dynamic_cast<GalleryQListViewItem*>(p_lvi);
+ GalleryTQListViewItem* p_glvi = dynamic_cast<GalleryTQListViewItem*>(p_lvi);
GalleryEdit dlg(this, p_glvi->GetGallery(), i18n("Edit Remote Gallery"));
- if (QDialog::Accepted == dlg.exec())
+ if (TQDialog::Accepted == dlg.exec())
{
p_glvi->Refresh();
mpGalleries->Save();
@@ -177,23 +177,23 @@ void GalleryList::slotUser2(void)
//================== Remove ======
void GalleryList::slotUser1(void)
{
- QListViewItem* p_lvi = mpGalleryList->selectedItem();
+ TQListViewItem* p_lvi = mpGalleryList->selectedItem();
if (!p_lvi)
{
- KMessageBox::error(kapp->activeWindow(), i18n("No gallery selected!"));
+ KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), i18n("No gallery selected!"));
}
else
{
if (KMessageBox::Yes ==
- KMessageBox::warningYesNo(kapp->activeWindow(),
+ KMessageBox::warningYesNo(TQT_TQWIDGET(kapp->activeWindow()),
i18n("Are you sure you want to remove this gallery? "
"All synchronisaton settings will be lost. "
"You cannot undo this action."),
i18n("Remove Remote Gallery"),
KStdGuiItem::yes(), KStdGuiItem::no(),
- QString::null, KMessageBox::Dangerous))
+ TQString(), KMessageBox::Dangerous))
{
- GalleryQListViewItem* p_glvi = dynamic_cast<GalleryQListViewItem*>(p_lvi);
+ GalleryTQListViewItem* p_glvi = dynamic_cast<GalleryTQListViewItem*>(p_lvi);
Gallery* p_gallery = p_glvi->GetGallery();
delete p_glvi;
mpGalleries->Remove(p_gallery);